@@ -16,12 +16,11 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LinuxVolume, Drive, Partition
+from netbox_storage.models import Filesystem, MountedVolume, Drive, Partition
 from virtualization.models import VirtualMachine
 
 
-class LinuxVolumeForm(NetBoxModelForm):
-    """Form for creating a new LinuxVolume object."""
+class MountedVolumeForm(NetBoxModelForm):
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         help_text="The Storage Cluster of the drive",
@@ -56,7 +55,7 @@ class LinuxVolumeForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = LinuxVolume
+        model = MountedVolume
 
         fields = (
             "drive",
@@ -68,10 +67,9 @@ class LinuxVolumeForm(NetBoxModelForm):
         )
 
 
-class LinuxVolumeFilterForm(NetBoxModelFilterSetForm):
-    """Form for filtering LinuxVolume instances."""
+class MountedVolumeFilterForm(NetBoxModelFilterSetForm):
 
-    model = LinuxVolume
+    model = MountedVolume
 
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
@@ -107,7 +105,7 @@ class LinuxVolumeFilterForm(NetBoxModelFilterSetForm):
     )
 
 
-class LinuxVolumeImportForm(NetBoxModelImportForm):
+class MountedVolumeImportForm(NetBoxModelImportForm):
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
         required=False
@@ -117,7 +115,7 @@ class LinuxVolumeImportForm(NetBoxModelImportForm):
         super().__init__(*args, **kwargs)
 
     class Meta:
-        model = LinuxVolume
+        model = MountedVolume
 
         fields = (
             "fs",
@@ -126,8 +124,8 @@ class LinuxVolumeImportForm(NetBoxModelImportForm):
         )
 
 
-class LinuxVolumeBulkEditForm(NetBoxModelBulkEditForm):
-    model = LinuxVolume
+class MountedVolumeBulkEditForm(NetBoxModelBulkEditForm):
+    model = MountedVolume
 
     path = CharField(
         required=False,
